package sample;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;

@Entity
public class RoleAssignment implements Serializable {

    private static final long serialVersionUID = 1L;

    @EmbeddedId
    private PrimaryKey primaryKey;

    @ManyToOne(optional = false)
    @JoinColumn(name = "ROLE_OID", nullable = false, updatable = false)
    private Role role;

    @ManyToOne(optional = false)
    @JoinColumn(name = "GLOBALACCOUNT_OID", nullable = false, updatable = false)
    private GlobalAccount globalAccount;

    public RoleAssignment() {
    }

    public RoleAssignment(Role role, GlobalAccount globalAccount, int priority) {
        this.primaryKey = new PrimaryKey(globalAccount.getOid(), priority);
        this.role = role;
        this.globalAccount = globalAccount;
    }

    public PrimaryKey getPrimaryKey() {
        return primaryKey;
    }

    public Role getRole() {
        return role;
    }

    public GlobalAccount getGlobalAccount() {
        return globalAccount;
    }

    @Embeddable
    public static class PrimaryKey implements Serializable {

        private static final long serialVersionUID = 1L;

        @Column(name = "GLOBALACCOUNT_OID_FOR_PK")
        private long globalAccountOid;

        @Column(name = "PRIORITY")
        private int priority;

        public PrimaryKey() {
        }

        public PrimaryKey(long globalAccountOid, int priority) {
            this.globalAccountOid = globalAccountOid;
            this.priority = priority;
        }

        @Override
        public int hashCode() {
            final int prime = 31;
            int result = 1;
            result = prime * result + (int) (globalAccountOid ^ (globalAccountOid >>> 32));
            result = prime * result + priority;
            return result;
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj)
                return true;
            if (obj == null)
                return false;
            if (getClass() != obj.getClass())
                return false;
            final PrimaryKey other = (PrimaryKey) obj;
            if (globalAccountOid != other.globalAccountOid)
                return false;
            if (priority != other.priority)
                return false;
            return true;
        }
    }

}
